==> haskell-cpphs-1.20.1-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-cpphs/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cpphs
version: 1.20.1
id: cpphs-1.20.1-46b13f1ef390a545ec653266d5170426
key: cpphs_GFZcQ7jDfUx2dsujmc7HXk
license: LGPL
copyright: 2004-2016, Malcolm Wallace
maintainer: Malcolm Wallace <Malcolm.Wallace@me.com>
homepage: http://projects.haskell.org/cpphs/
synopsis: A liberalised re-implementation of cpp, the C pre-processor.
description:
    Cpphs is a re-implementation of the C pre-processor that is both
    more compatible with Haskell, and itself written in Haskell so
    that it can be distributed with compilers.
    .
    This version of the C pre-processor is pretty-much
    feature-complete and compatible with traditional (K&R)
    pre-processors.  Additional features include: a plain-text mode;
    an option to unlit literate code files; and an option to turn
    off macro-expansion.
category: Development
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
exposed-modules:
    Language.Preprocessor.Cpphs Language.Preprocessor.Unlit
hidden-modules: Language.Preprocessor.Cpphs.CppIfdef
                Language.Preprocessor.Cpphs.HashDefine
                Language.Preprocessor.Cpphs.MacroPass
                Language.Preprocessor.Cpphs.Options
                Language.Preprocessor.Cpphs.Position
                Language.Preprocessor.Cpphs.ReadFirst
                Language.Preprocessor.Cpphs.RunCpphs
                Language.Preprocessor.Cpphs.SymTab
                Language.Preprocessor.Cpphs.Tokenise
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cpphs-1.20.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/cpphs-1.20.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/cpphs-1.20.1
hs-libraries: HScpphs-1.20.1-GFZcQ7jDfUx2dsujmc7HXk
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
    polyparse-1.11-32e1e4b83edd269be9945c81b189424b
haddock-interfaces: /usr/share/doc/haskell-cpphs/html/cpphs.haddock
haddock-html: /usr/share/doc/haskell-cpphs/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cpphs-1.20.1-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-cpphs/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cpphs
version: 1.20.1
id: cpphs-1.20.1-b531b91e3eedabd84a3f357cbe12d473
key: cpphs_4BOba56UoHy4GZONxR3yKz
license: LGPL
copyright: 2004-2016, Malcolm Wallace
maintainer: Malcolm Wallace <Malcolm.Wallace@me.com>
homepage: http://projects.haskell.org/cpphs/
synopsis: A liberalised re-implementation of cpp, the C pre-processor.
description:
    Cpphs is a re-implementation of the C pre-processor that is both
    more compatible with Haskell, and itself written in Haskell so
    that it can be distributed with compilers.
    .
    This version of the C pre-processor is pretty-much
    feature-complete and compatible with traditional (K&R)
    pre-processors.  Additional features include: a plain-text mode;
    an option to unlit literate code files; and an option to turn
    off macro-expansion.
category: Development
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
exposed-modules:
    Language.Preprocessor.Cpphs Language.Preprocessor.Unlit
hidden-modules: Language.Preprocessor.Cpphs.CppIfdef
                Language.Preprocessor.Cpphs.HashDefine
                Language.Preprocessor.Cpphs.MacroPass
                Language.Preprocessor.Cpphs.Options
                Language.Preprocessor.Cpphs.Position
                Language.Preprocessor.Cpphs.ReadFirst
                Language.Preprocessor.Cpphs.RunCpphs
                Language.Preprocessor.Cpphs.SymTab
                Language.Preprocessor.Cpphs.Tokenise
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/cpphs-1.20.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/cpphs-1.20.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/cpphs-1.20.1
hs-libraries: HScpphs-1.20.1-4BOba56UoHy4GZONxR3yKz
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
    polyparse-1.11-e9f1a767e0f506fecd31d2edb677e294
haddock-interfaces: /usr/share/doc/haskell-cpphs/html/cpphs.haddock
haddock-html: /usr/share/doc/haskell-cpphs/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
